netapp_ontap.models.zapp_nvme_components API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.zapp_nvme_components`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ZappNvmeComponentsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ZappNvmeComponents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `name: str GET POST PATCH`

    The name of the application component.

  `namespace_count: Size GET POST PATCH`

    The number of namespaces supported per request, with a total limit of 1024 per volume.

  `os_type: str GET POST PATCH`

    The name of the host OS running the application.

    Valid choices:

    - aix
    - linux
    - vmware
    - windows
  `performance: ZappNvmeComponentsPerformance GET POST PATCH`

    The performance field of the zapp_nvme_components.

  `qos: NasApplicationComponentsQos GET POST`

    The qos field of the zapp_nvme_components.

  `subsystem: ZappNvmeComponentsSubsystem GET POST PATCH`

    components.subsystem

  `tiering: ZappNvmeComponentsTiering GET POST PATCH`

    application-components.tiering

  `total_size: Size GET POST PATCH`

    The total size of the component, spread across member namespaces. Usage: {<integer>[KB|MB|GB|TB|PB]}